@@ -34,7 +34,7 @@ HOUSE_NO_EXP4 = "((?:^|,|^.+ )((\d{1,3})[/ ]\d{1,3})[ ,]+)\w"
 HOUSE_NO_EXP5 = "((?:^|,|^.+ )(?:No(?:\.|\. | ))?(\d{1,4})[ ,]+)\w"
 VILLAGE_EXP = "(?i)(?:^|,| )(?:หมู่ที่|หมู่ที่|หมู่|ม .|ม.|Moo|Mu)\s?(\d+)"
 ROAD_EXP1 = "(?i)(?:^|,| )(?:(Soi [A-Za-z\- ]+(?: \d{1,4})?)|((?:ซอย|ถนน) [^ ]+(?: \d{1,4})?)|((?:ถ |ถ|ชบ)\.[^ ]+(?: \d{1,4})?))(?: |,|$)"
-ROAD_EXP2 = "(?i)(?:^|(?:[^A-Za-z\-\. ]))([A-Za-z\-\. ]+ (?:\d{1,4} )?(?:Soi|Road|Raod|Rd\.?|Highway|Route|Alley)(?: \d{1,4})?)(?: |,|$)"
+ROAD_EXP2 = "(?i)(?:^|(?:[^A-Za-z\-\. ]))([A-Za-z\-\. ]+ (?:\d{1,4} )?(?:Soi|Road|Raod|Rd\.?|Highway|Route|Alley|Avenue|Ave\.?)(?: \d{1,4})?)(?: |,|$)"
 
 
 def load_thai_admin_areas(dir_path):
@@ -523,6 +523,19 @@ def extract_admin_areas(text, print_log=False):
 
 
 def to_thai_address_object(addr_text, load_admin_area_path=None):
+    if pd.isna(addr_text) or addr_text == "":
+        return {
+            "house_no": None,
+            "moo_no": None,
+            "street": None,
+            "admin_lv3": None,
+            "admin_lv2": None,
+            "admin_lv1": None,
+            "admin_sim": 0,
+            "postal_code": None,
+            "plus_code": None
+        }
+
     if load_admin_area_path is not None:
         load_thai_admin_areas(load_admin_area_path)
 
@@ -566,6 +579,9 @@ def to_thai_address_object(addr_text, load_admin_area_path=None):
 def match_thai_vendor_addresses(customer_address, vendor_addresses, text_dist_thresh=0.85, validate_pinpoint_customer_address=False):
     result = {}
 
+    if pd.isna(customer_address) or customer_address == "":
+        return result
+
     if customer_address is not None:
         if type(customer_address) == str:
             if validate_pinpoint_customer_address and (customer_address == ""):
